@@ -4,7 +4,6 @@ import json
 import os
 from datetime import datetime, timezone
 from enum import Enum
-from json import JSONDecodeError
 from pathlib import Path
 from typing import (
     IO,
@@ -38,6 +37,8 @@ pysnooper.tracer.DISABLED = True
 
 DEFAULT_BASE_CLASS: str = 'pydantic.BaseModel'
 
+# ALL_MODEL: str = '#all#'
+
 
 def enable_debug_message() -> None:  # pragma: no cover
     pysnooper.tracer.DISABLED = False
@@ -123,6 +124,8 @@ def generate(
     snake_case_field: bool = False,
     strip_default_none: bool = False,
     aliases: Optional[Mapping[str, str]] = None,
+    disable_timestamp: bool = False,
+    allow_population_by_field_name: bool = False,
 ) -> None:
     if input_file_type == InputFileType.Auto:
         try:
@@ -174,6 +177,7 @@ def generate(
         snake_case_field=snake_case_field,
         strip_default_none=strip_default_none,
         aliases=aliases,
+        allow_population_by_field_name=allow_population_by_field_name,
     )
 
     with chdir(output):
@@ -193,8 +197,9 @@ def generate(
     timestamp = datetime.now(timezone.utc).replace(microsecond=0).isoformat()
     header = f'''\
 # generated by datamodel-codegen:
-#   filename:  {Path(input_name).name}
-#   timestamp: {timestamp}'''
+#   filename:  {Path(input_name).name}'''
+    if not disable_timestamp:
+        header += f'\n#   timestamp: {timestamp}'
 
     file: Optional[IO[Any]]
     for path, body in modules.items():
