@@ -1,5 +1,5 @@
 from pydantic import BaseModel, Extra
-from typing import List, Optional
+from typing import Dict, List, Optional
 from __future__ import annotations
 
 
@@ -43,4 +43,22 @@ class Event(BaseModel):
 
 
 class Result(BaseModel):
-    event: Optional[Event] = None
\ No newline at end of file
+    event: Optional[Event] = None
+
+
+class Broken(BaseModel):
+    foo: Optional[str] = None
+    bar: Optional[int] = None
+
+
+class Test(BaseModel):
+    broken: Optional[Dict[str, Broken]] = None
+
+
+class Tags(BaseModel):
+    __root__: List[str]
+
+
+class FileSetUpload(BaseModel):
+    task_id: Optional[str] = None
+    tags: Dict[str, Tags]
\ No newline at end of file
